(sec_overview)=

# Overview page

![Overview Page](tsbrowse:example.tsbrowse:overview)

This page gives high-level details on the loaded tree sequence including 
the number of each type of object and the (uncompressed) disk space used
by each.
Provenance information is also displayed, showing the commands used to
generate the tree sequence, if available.